import { useState, useEffect } from "react";
import { Link, useLocation } from "wouter";
import { Menu, X, Calendar, ChevronDown, ChevronUp } from "lucide-react";
import LanguageSwitcher from "./LanguageSwitcher";
import { useLanguageNavigation } from "@/hooks/useLanguageNavigation";

export default function Navigation() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const [isMobileServicesOpen, setIsMobileServicesOpen] = useState(false);
  const [location] = useLocation();
  const { getLocalizedUrl } = useLanguageNavigation();

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 50);
    };

    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const scrollToTop = () => {
    window.scrollTo({ top: 0, behavior: 'auto' });
  };



  return (
    <nav className={`fixed top-0 left-0 right-0 z-50 transition-all duration-300 ${
      isScrolled 
        ? 'bg-white/98 backdrop-blur-md shadow-sm border-b border-gray-100/80' 
        : 'bg-white/90 backdrop-blur-sm'
    }`} style={{ 
      position: 'fixed',
      top: 0,
      left: 0,
      right: 0,
      zIndex: 50
    }}>
      <div className="max-w-7xl mx-auto px-6 sm:px-8 lg:px-12">
        <div className="flex justify-between items-center h-20">
          {/* Ultra-premium logo */}
          <div className="flex-shrink-0">
            <Link href="/" onClick={scrollToTop} className="relative group block cursor-pointer">
              {/* Minimalist luxury logo */}
              <div className="flex items-center space-x-1">
                <div className="w-8 h-8 border border-accent/30 rounded-sm flex items-center justify-center bg-white/80 backdrop-blur-sm group-hover:border-accent/50 transition-colors duration-300">
                  <span className="text-accent font-thin text-xl">M</span>
                </div>
                <div className="w-1 h-6 bg-accent/20"></div>
                <span className="text-2xl font-thin tracking-[0.1em] text-foreground group-hover:text-accent transition-colors duration-300">M</span>
              </div>
            </Link>
          </div>

          {/* Executive navigation menu */}
          <div className="hidden lg:flex items-center space-x-8">
            <Link href={getLocalizedUrl('/')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en' || location === '/nl' || location === '/' ? 'text-accent' : 'text-neutral-gray'}`}>
              Home
            </Link>
            <Link href={getLocalizedUrl('/origin')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en/origin' || location === '/nl/origin' || location === '/origin' || location === '/why' ? 'text-accent' : 'text-neutral-gray'}`}>
              Origin
            </Link>
            <div className="relative group">
              <span className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group cursor-default ${location === '/en/services' || location === '/nl/services' || location === '/services' || location === '/methods' || location?.startsWith('/en/services/') || location?.startsWith('/nl/services/') || location?.startsWith('/services/') || location === '/executive-access' || location === '/mentoring' ? 'text-accent' : 'text-neutral-gray'}`}>
                Services
              </span>
              
              {/* Services Dropdown */}
              <div className="absolute top-full left-0 mt-2 opacity-0 invisible group-hover:opacity-100 group-hover:visible transition-all duration-200 z-50">
                <div className="bg-white/95 backdrop-blur-md border border-gray-100/50 rounded-lg shadow-xl py-3 min-w-[320px]">
                  {/* Unified Team Development Category */}
                  <div className="px-6 py-3 bg-accent/10 border-l-4 border-accent">
                    <div className="text-sm font-semibold text-accent uppercase tracking-wider">
                      Unified Team Development
                    </div>
                  </div>
                  <Link 
                    href={getLocalizedUrl('/services/unified-team-activation')} 
                    onClick={scrollToTop}
                    className="block pl-10 pr-6 py-3 text-sm text-gray-700 hover:text-accent hover:bg-accent/5 transition-colors duration-200 border-l-4 border-transparent hover:border-accent/30"
                  >
                    <div className="font-medium">Activation</div>
                    <div className="text-xs text-gray-500 mt-1">Kick-off workshop for behavioral change</div>
                  </Link>
                  <Link 
                    href={getLocalizedUrl('/services/unified-team-breakthrough')} 
                    onClick={scrollToTop}
                    className="block pl-10 pr-6 py-3 text-sm text-gray-700 hover:text-accent hover:bg-accent/5 transition-colors duration-200 border-l-4 border-transparent hover:border-accent/30"
                  >
                    <div className="font-medium">Breakthrough</div>
                    <div className="text-xs text-gray-500 mt-1">4–6 week intervention for teams that are stuck</div>
                  </Link>
                  <Link 
                    href={getLocalizedUrl('/services/unified-team-protocol')} 
                    onClick={scrollToTop}
                    className="block pl-10 pr-6 py-3 text-sm text-gray-700 hover:text-accent hover:bg-accent/5 transition-colors duration-200 border-l-4 border-transparent hover:border-accent/30"
                  >
                    <div className="font-medium">Protocol</div>
                    <div className="text-xs text-gray-500 mt-1">6-month culture anchoring for core teams</div>
                  </Link>
                  
                  {/* Separator */}
                  <div className="mx-6 my-3 h-px bg-gray-200"></div>
                  
                  {/* Leadership 1-on-1 Upgrade Category */}
                  <div className="px-6 py-3 bg-accent/10 border-l-4 border-accent">
                    <div className="text-sm font-semibold text-accent uppercase tracking-wider">
                      Leadership 1-on-1 Upgrade
                    </div>
                  </div>
                  <Link 
                    href={getLocalizedUrl('/services/command-and-clarity')} 
                    onClick={scrollToTop}
                    className="block pl-10 pr-6 py-3 text-sm text-gray-700 hover:text-accent hover:bg-accent/5 transition-colors duration-200 border-l-4 border-transparent hover:border-accent/30"
                  >
                    <div className="font-medium">Command & Clarity™</div>
                    <div className="text-xs text-gray-500 mt-1">10-week 1-on-1 for leaders</div>
                  </Link>
                </div>
              </div>
            </div>
            <Link href={getLocalizedUrl('/keynotes')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en/keynotes' || location === '/nl/keynotes' || location === '/keynotes' ? 'text-accent' : 'text-neutral-gray'}`}>
              Keynotes
            </Link>
            <Link href={getLocalizedUrl('/insights')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en/insights' || location === '/nl/insights' || location === '/insights' || location?.startsWith('/en/insights/') || location?.startsWith('/nl/insights/') || location?.startsWith('/insights/') ? 'text-accent' : 'text-neutral-gray'}`}>
              Insights
            </Link>

            <Link href={getLocalizedUrl('/media')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en/media' || location === '/nl/media' || location === '/media' ? 'text-accent' : 'text-neutral-gray'}`}>
              Media
            </Link>

            <Link href={getLocalizedUrl('/services')} onClick={scrollToTop} className={`nav-link text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 relative group ${location === '/en/services' || location === '/nl/services' || location === '/services' ? 'text-accent' : 'text-neutral-gray'}`}>
              Our Approach
            </Link>

            {/* Language switcher - Temporarily hidden until all pages are translated */}
            {/* <LanguageSwitcher /> */}
          </div>

          {/* Premium CTA */}
          <div className="hidden xl:block flex-shrink-0">
            <Link 
              href={getLocalizedUrl('/contact')}
              onClick={scrollToTop}
              className="btn-secondary text-xs whitespace-nowrap"
            >
              Connect
            </Link>
          </div>

          {/* Mobile menu button */}
          <div className="lg:hidden flex items-center">
            <button
              onClick={() => setIsMobileMenuOpen(!isMobileMenuOpen)}
              className="p-2 rounded-md text-neutral-gray hover:text-accent transition-colors duration-200"
              aria-label="Toggle mobile menu"
            >
              {isMobileMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </button>
          </div>
        </div>

        {/* Mobile menu */}
        {isMobileMenuOpen && (
          <div className="lg:hidden">
            <div className="px-2 pt-2 pb-3 space-y-1 bg-white/95 backdrop-blur-md border-t border-gray-100/50">
              <Link href={getLocalizedUrl('/')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en' || location === '/nl' || location === '/' ? 'text-accent' : 'text-neutral-gray'}`}>
                Home
              </Link>
              <Link href={getLocalizedUrl('/origin')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/origin' || location === '/nl/origin' || location === '/origin' || location === '/why' ? 'text-accent' : 'text-neutral-gray'}`}>
                Origin
              </Link>
              
              {/* Mobile Services Dropdown */}
              <div>
                <button 
                  onClick={() => setIsMobileServicesOpen(!isMobileServicesOpen)}
                  className={`flex items-center justify-between w-full px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/services' || location === '/services' || location === '/methods' || location?.startsWith('/en/services/') || location?.startsWith('/services/') || location === '/executive-access' || location === '/mentoring' ? 'text-accent' : 'text-neutral-gray'}`}
                >
                  Services
                  {isMobileServicesOpen ? <ChevronUp size={16} /> : <ChevronDown size={16} />}
                </button>
                
                {isMobileServicesOpen && (
                  <div className="pl-6 space-y-1 bg-gray-50/50">
                    {/* Unified Team Development */}
                    <div className="px-3 py-2 text-xs font-semibold text-accent uppercase tracking-wider">
                      Unified Team Development
                    </div>
                    <Link href={getLocalizedUrl('/services/unified-team-activation')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); setIsMobileServicesOpen(false); }} className="block px-3 py-1 text-sm text-neutral-gray hover:text-accent transition-colors duration-200">
                      Activation
                    </Link>
                    <Link href={getLocalizedUrl('/services/unified-team-breakthrough')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); setIsMobileServicesOpen(false); }} className="block px-3 py-1 text-sm text-neutral-gray hover:text-accent transition-colors duration-200">
                      Breakthrough
                    </Link>
                    <Link href={getLocalizedUrl('/services/unified-team-protocol')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); setIsMobileServicesOpen(false); }} className="block px-3 py-1 text-sm text-neutral-gray hover:text-accent transition-colors duration-200">
                      Protocol
                    </Link>
                    
                    {/* Leadership 1-on-1 */}
                    <div className="px-3 py-2 text-xs font-semibold text-accent uppercase tracking-wider mt-2">
                      Leadership 1-on-1 Upgrade
                    </div>
                    <Link href={getLocalizedUrl('/services/command-and-clarity')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); setIsMobileServicesOpen(false); }} className="block px-3 py-1 text-sm text-neutral-gray hover:text-accent transition-colors duration-200">
                      Command & Clarity™
                    </Link>
                  </div>
                )}
              </div>
              <Link href={getLocalizedUrl('/keynotes')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/keynotes' || location === '/nl/keynotes' || location === '/keynotes' ? 'text-accent' : 'text-neutral-gray'}`}>
                Keynotes
              </Link>
              <Link href={getLocalizedUrl('/insights')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/insights' || location === '/nl/insights' || location === '/insights' || location?.startsWith('/en/insights/') || location?.startsWith('/nl/insights/') || location?.startsWith('/insights/') ? 'text-accent' : 'text-neutral-gray'}`}>
                Insights
              </Link>
              <Link href={getLocalizedUrl('/media')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/media' || location === '/nl/media' || location === '/media' ? 'text-accent' : 'text-neutral-gray'}`}>
                Media
              </Link>
              <Link href={getLocalizedUrl('/services')} onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }} className={`block px-3 py-2 text-sm font-light uppercase tracking-[0.1em] hover:text-accent transition-all duration-200 ${location === '/en/services' || location === '/nl/services' || location === '/services' ? 'text-accent' : 'text-neutral-gray'}`}>
                Our Approach
              </Link>

              {/* Mobile Language Switcher - Temporarily hidden until all pages are translated */}
              <div className="pt-4 border-t border-gray-100/50 space-y-3">
                {/* <LanguageSwitcher /> */}
                
                <Link 
                  href={getLocalizedUrl('/contact')}
                  onClick={() => { scrollToTop(); setIsMobileMenuOpen(false); }}
                  className="btn-secondary text-xs w-full text-center"
                >
                  Connect
                </Link>
              </div>
            </div>
          </div>
        )}
      </div>
    </nav>
  );
}
